# Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
# SPDX-License-Identifier: Apache-2.0

import os

from agenteval import jinja_env
from agenteval.metrics import calculate_pass_rate_metric
from agenteval.test import Test, TestResult

_TEMPLATE_ROOT = "summary"
_TEMPLATE_FILE_NAME = "agenteval_summary.md.jinja"


def create_markdown_summary(
    work_dir: str,
    pass_count: int,
    num_tests: int,
    tests: list[Test],
    test_results: list[TestResult],
):
    """
    Create a Markdown summary of the test results.

    This function uses a Jinja2 template to render a Markdown summary of the
    provided tests and test results.

    The summary is then written to a file in the specified working directory.

    Args:
        work_dir (str): The directory where the summary file will be created.
        pass_count (int): The number of tests that passed.
        num_tests (int): The total number of tests.
        tests (list[Test]): A list of tests.
        test_results (list[TestResult]): A list of test results.

    Returns:
        None
    """
    template = jinja_env.get_template(os.path.join(_TEMPLATE_ROOT, _TEMPLATE_FILE_NAME))
    summary_path = os.path.join(work_dir, os.path.splitext(_TEMPLATE_FILE_NAME)[0])

    metrics = {"pass_rate": calculate_pass_rate_metric(pass_count, num_tests)}

    rendered = template.render(
        tests=tests, results=test_results, zip=zip, metrics=metrics
    )

    _write_summary(summary_path, rendered)


def _write_summary(path: str, summary: str):
    with open(path, "w+") as f:
        f.write(summary)



# Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
# SPDX-License-Identifier: Apache-2.0

from agenteval.evaluators.model_config.bedrock_model_config import BedrockModelConfig

""""
# NOTE: Models that are prefixed with `us.` are not supported by Bedrock with on demand inference, so we specify
# the default USA cross region inference profile
# doc: https://docs.aws.amazon.com/bedrock/latest/userguide/inference-profiles-support.html
"""

# Claude Models

DEFAULT_CLAUDE_3_MODEL_CONFIG = BedrockModelConfig(
    model_id="anthropic.claude-3-sonnet-20240229-v1:0",
    request_body={
        "anthropic_version": "bedrock-2023-05-31",
        "max_tokens": 300,
        "system": None,
        "messages": [
            {
                "role": "user",
                "content": [
                    {"type": "text", "text": None},
                ],
            }
        ],
        "temperature": 0,
        "top_p": 1,
        "top_k": 250,
    },
)

DEFAULT_CLAUDE_3_5_MODEL_CONFIG = BedrockModelConfig(
    model_id="anthropic.claude-3-5-sonnet-20240620-v1:0",
    request_body={
        "anthropic_version": "bedrock-2023-05-31",
        "max_tokens": 300,
        "system": None,
        "messages": [
            {
                "role": "user",
                "content": [
                    {"type": "text", "text": None},
                ],
            }
        ],
        "temperature": 0,
        "top_p": 1,
        "top_k": 250,
    },
)

DEFAULT_CLAUDE_US_3_7_MODEL_CONFIG = BedrockModelConfig(
    model_id="us.anthropic.claude-3-7-sonnet-20250219-v1:0",
    request_body={
        "anthropic_version": "bedrock-2023-05-31",
        "max_tokens": 300,
        "system": None,
        "messages": [
            {
                "role": "user",
                "content": [
                    {"type": "text", "text": None},
                ],
            }
        ],
        "temperature": 0,
        "top_p": 1,
        "top_k": 250,
    },
)

DEFAULT_CLAUDE_HAIKU_3_5_US_MODEL_CONFIG = BedrockModelConfig(
    model_id="us.anthropic.claude-3-5-haiku-20241022-v1:0",
    request_body={
        "anthropic_version": "bedrock-2023-05-31",
        "max_tokens": 300,
        "system": None,
        "messages": [
            {
                "role": "user",
                "content": [
                    {"type": "text", "text": None},
                ],
            }
        ],
        "temperature": 0,
        "top_p": 1,
        "top_k": 250,
    },
)

# LLama Models
DEFAULT_LLAMA_3_3_70B_US_MODEL_CONFIG = BedrockModelConfig(
    model_id="us.meta.llama3-3-70b-instruct-v1:0",
    request_body={
        "prompt": None,
        "max_gen_len": 300,
        "temperature": 0,
        "top_p": 1,
    },
)



# Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
# SPDX-License-Identifier: Apache-2.0

from .target_response import TargetResponse
from .base_target import BaseTarget
from .boto3_target import Boto3Target
from .target_factory import TargetFactory

__all__ = ["TargetResponse", "BaseTarget", "TargetFactory", "Boto3Target"]



# Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
# SPDX-License-Identifier: Apache-2.0

from .base_evaluator import BaseEvaluator
from .evaluator_factory import EvaluatorFactory

__all__ = ["BaseEvaluator", "EvaluatorFactory"]



# Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
# SPDX-License-Identifier: Apache-2.0

import uuid

from agenteval.targets import Boto3Target, TargetResponse

_SERVICE_NAME = "lexv2-runtime"


class LexV2Target(Boto3Target):
    def __init__(self, bot_id: str, bot_alias_id: str, locale_id: str, **kwargs):
        super().__init__(boto3_service_name=_SERVICE_NAME, **kwargs)
        self._bot_id = bot_id
        self._bot_alias_id = bot_alias_id
        self._locale_id = locale_id
        self._session_id = str(uuid.uuid4())

    def invoke(self, prompt: str) -> TargetResponse:
        """Invoke the target with a prompt.

        Args:
            prompt(str): The prompt to send to the target.

        Returns:
            TargetResponse: The response from the target.
        """
        args = {
            "botId": self._bot_id,
            "botAliasId": self._bot_alias_id,
            "localeId": self._locale_id,
            "sessionId": self._session_id,
            "text": prompt,
        }

        response = self.boto3_client.recognize_text(**args)
        if response["sessionState"]["dialogAction"]["type"] == "Close":
            completion = "Completed"
        else:
            completion = response["messages"][0]["content"]
        interpretation_data = [response]

        return TargetResponse(
            response=completion, data={"lexv2_interpretation_data": interpretation_data}
        )
